#!/bin/sh -e

case "$1" in
"")
  PLATFORM=i686
  CROSS_BUILD="none"
  ;;
x86)
  PLATFORM=$1
  CROSS_BUILD="none"
  ;;
at4x0a)
  CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
  PLATFORM=$1
  ;;
titan2)
  CROSS_TARGET="arm-none-linux-gnueabi"
  PLATFORM=$1
  ;;
s3c24xx)
  CROSS_TARGET="arm-linux"
  PLATFORM=$1
  ;;
s3c64xx)
  CROSS_TARGET="arm-none-linux-gnueabi"
  PLATFORM=$1
  ;;
*)
  echo "$0: ERROR: Unknown platform \"$1\"."
  exit 1
  ;;
esac

PROGNAME="dosfstools"
SRCDIR="${PWD}"

INSDIR="${PWD}/ins-${PLATFORM}"
if [ $CROSS_BUILD  == "none" ]; then
 export CC=gcc
else
 export CC=${CROSS_TARGET}-gcc
fi

echo "**** Building ${PROGNAME} for ${PLATFORM}..."
# do a clean build all the time to erase possible object files for another platform
rm -rf $INSDIR
make clean all

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make PREFIX="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"
set -x
ls -l "${INSDIR}/sbin"

# EOF
